package main

import (
	"context"
	"os"
	"os/signal"

	"gitea.libretechconsulting.com/rmcguire/go-app/pkg/app"
	"gitea.libretechconsulting.com/rmcguire/go-app/pkg/srv"
	"golang.org/x/sys/unix"

	"gitea.libretechconsulting.com/rmcguire/ambient-weather-local-exporter/pkg/ambient"
	"gitea.libretechconsulting.com/rmcguire/ambient-weather-local-exporter/pkg/ambient/ambienthttp"
	"gitea.libretechconsulting.com/rmcguire/ambient-weather-local-exporter/pkg/ambient/config"
)

const defaultMetricPrefix = "weather"

func main() {
	ctx, cncl := signal.NotifyContext(context.Background(), os.Kill, unix.SIGTERM)
	defer cncl()

	// Config type for app, which implements go-app/config.AppConfig
	awConfig := &config.AmbientLocalExporterConfig{
		MetricPrefix:    defaultMetricPrefix,
		WeatherStations: make([]config.WeatherStation, 0),
	}

	// Read config and environment, set up logging, load up
	// an appCtx, and prepare ambient weather local exporter
	ctx, awConfig = app.MustLoadConfigInto(ctx, awConfig)

	// Prepare the exporter
	aw := ambient.New(ctx, awConfig).Init()

	// Define and prepare the app
	awApp := app.App{
		AppContext: ctx,
		HTTP: &app.AppHTTP{
			Funcs: []srv.HTTPFunc{
				{
					Path:        "/weatherstation/updateweatherstation.php",
					HandlerFunc: aw.GetWundergroundHandlerFunc(ctx),
				},
				{
					Path:        "/data/report",
					HandlerFunc: aw.GetAWNHandlerFunc(ctx),
				},
			},
			CustomListener: ambienthttp.NewAWNMutatingListener(ctx,
				awConfig.HTTP.Listen), // Necessary to fix certain bad AWN firmware
			HealthChecks: []srv.HealthCheckFunc{
				// TODO: Implement
				func(ctx context.Context) error {
					return nil
				},
			},
		},
	}

	// Run and wait
	awApp.MustRun()
	<-awApp.Done()
}
